@@ -1,5 +1,5 @@
-from typing import Dict
 import platform
+from typing import Dict
 
 IS_WINDOWS = platform.system() == "Windows"
 
@@ -13,12 +13,3 @@ def get_process_list() -> Dict:
     Returns dictionary mapping process id to process name
     """
     return {proc.pid: proc.name() for proc in psutil.process_iter()}
-
-
-def is_numeric(value):
-    try:
-        float(value)
-    except ValueError:
-        return False
-    else:
-        return float(value).is_integer()
